//*************************************************
// modulo: settings.h
// autore: Longhi Ferdinando
// data: 08/06/2012
// descrizione: modulo per centralina per automatizzare le persiane
// picmicro: PIC16F88
// clock: 8MHz interno
// NOTE:gestione della velocit con PWM
//*************************************************


// definisco le porte con termini facili da ricordare


#define Out1	RA0	// uscita per apertura prima anta
#define Out2	RA1	// uscita per apertura seconda anta
#define Out3	RA2	// uscita per chiusura seconda anta
#define Out4	RA3	// uscita per chiusura prima anta
#define Amp		RA4	// Ingresso per maperostop. Se 1 motore in blocco
#define Pul		RB0	// Ingresso pulsante Apre/blocca/Chiudi
#define OutPWM	RB3	// uscita PWM per rallentamento
unsigned int duty=0;//valore duty cycle CCP1
unsigned short Time =0;
unsigned char Sec=0;//variabile per il conteggio dei secondi
unsigned char TimeAmp=0;//variabile per il conteggio dei secondi in aperostop
unsigned char TimeRal=0;//variabile per il conteggio dei secondi di rallentamento
unsigned char TRal=5;//tempo di rallentamento
unsigned char Time1=5;//tempo apertura anta 1
unsigned char Time2=6;//tempo apertura anta 2
unsigned char Time3=6;//tempo chiusura anta 2
unsigned char Time4=6;//tempo chiusura anta 1
bit Brk=0;//flag per uscire dalla routine while


void settings(void)
	{
//Usero' le porte A solo come digitali e non con analogiche
	ANSEL=0b00000000;
// Abilito l'scillatore interno pag. 40 del datasheet PIC16F88
	OSCCON=0b01111100;//Freq.=8Mhz

// Posso correggere l'errore dell'oscillatore interno pag. 88 del datasheet PIC16F88
	OSCTUNE=0b00000000;//Non correggo

// Abilito l'interrupt 
	TMR0IE=1; // abilito la gestione dell'interrupt sull'overflow del Timer0
	GIE=1; // abilito la gestione generale degli interrupt

// Definisco il registro OPTION pag. 18 del datasheet PIC16F88
OPTION_REG=0b10000100;
// Impostazione Registro Opzioni
// bit 0 -> PS0    Prescaler Rate Select bit 0
// bit 1 -> PS1    Prescaler Rate Select bit 1
// bit 2 -> PS2    Prescaler Rate Select bit 2
// bit 3 -> PSA    Prescaler assegnato al Timer0 (1=al Watchdog Timer)
// bit 4 -> T0SE   Incremento Timer0 su transizione: 0=low->high 1=high->low
// bit 5 -> T0CS   Clock Timer0 da clock interno (1=su transizione pin T0CKI)
// bit 6 -> INTEDG Interrupt (INT) edge (1=salita 0=discesa)
// bit 7 -> RBPU   Resistenze pull-up su porta B (1=off 0=on)

	TRISA=0b10110000;		
// Impostazione porta RA
// RA0  -> out1 per apertura anta 1
// RA1  -> out2 per apertura anta 2
// RA2  -> out3 per chiusura anta 2
// RA3  -> out4 per chiusura anta 1
// RA4  -> Ingresso per maperostop. Se 1 motore in blocco
// RA5  -> Ingresso disponibile - Pu essere solo ingresso
// RA6  -> out6 disponibile
// RA7  -> Ingresso disponibile

	TRISB=0b01000111;		
// Impostazione porta RB
// RB0  -> Ingresso pulsante Apre/blocca/Chiudi
// RB1  -> Ingresso PRG per entrare in programm.
// RB2  -> Ingresso per RX Bus 485
// RB3  -> Out per PWM
// RB4  -> Out per LED di programmazione
// RB5  -> Out per TX Bus 485
// RB6  -> out6 disponibile
// RB7  -> out7 disponibile

	
	TMR0=194; // Imposto Timer0 per avere un interrupt ogni micro secondo
	}
